@@ -6,31 +6,7 @@ import argparse
 import sys
 import datetime
 from dateutil.tz import tzlocal
-
-
-assume_role_cache: dict = {}
-
-def assumed_role_session(role_arn: str, base_session: botocore.session.Session = None):
-    base_session = base_session or boto3.session.Session()._session
-    fetcher = botocore.credentials.AssumeRoleCredentialFetcher(
-        client_creator = base_session.create_client,
-        source_credentials = base_session.get_credentials(),
-        role_arn = role_arn,
-        extra_args = {
-        #    'RoleSessionName': None # set this if you want something non-default
-        }
-    )
-    creds = botocore.credentials.DeferredRefreshableCredentials(
-        method = 'assume-role',
-        refresh_using = fetcher.fetch_credentials,
-        time_fetcher = lambda: datetime.datetime.now(tzlocal())
-    )
-    botocore_session = botocore.session.Session()
-    botocore_session._credentials = creds
-    return boto3.Session(botocore_session = botocore_session)
-
-# usage:
-#session = assumed_role_session('arn:aws:iam::ACCOUNTID:role/ROLE_NAME')
+import role
 
 def main():
     parser = argparse.ArgumentParser(description='Set desired EC2 instance state')
@@ -60,7 +36,7 @@ def main():
     print ('instances:' + str(instances))
 
     if arg.role_arn:
-      session = assumed_role_session(arg.role_arn)
+      session = role.assumed_role_session(arg.role_arn)
       ec2 = session.client('ec2', region_name=arg.region)
     else:
       ec2 = boto3.client('ec2', region_name=arg.region)
