@@ -95,6 +95,16 @@ def main():
                         help="Filer result by type.")
     parser.add_argument('-s', '--status',
                         help="Filter result by status." )
+    parser.add_argument('-z', '--zone',
+                        help="Filter result by Availability Zone.")
+    parser.add_argument('-v', '--vpc',
+                        help="Filter result by VPC Id.")
+    parser.add_argument('-S', '--subnet',
+                        help="Filter result by Subnet Id.")
+    parser.add_argument('--public_ip',
+                        help="Filter result by public ip address. You can provide the whole IP address string or just a portion of it.")
+    parser.add_argument('--private_ip',
+                        help="Filter result by private ip adreess. You can provide the whole IP address string or just a portion of it.")
     parser.add_argument('-l', '--id_list',
                         nargs='+', type=str,
                         help="Do not filter the result. Provide a InstanceIds list instead." )
@@ -135,6 +145,21 @@ def main():
     if arg.status:
         filter.append({'Name': 'instance-state-name', 'Values': ["*" + arg.status + "*"]})
 
+    if arg.vpc:
+        filter.append({'Name': 'vpc-id', 'Values': ["*" + arg.vpc + "*"]})
+
+    if arg.zone:
+        filter.append({'Name': 'availability-zone', 'Values': ["*" + arg.zone + "*"]})
+    
+    if arg.subnet:
+        filter.append({'Name': 'subnet-id', 'Values': ["*" + arg.subnet + "*"]})
+
+    if arg.public_ip:
+        filter.append({'Name': 'ip-address', 'Values': ["*" + arg.public_ip + "*"]})
+
+    if arg.private_ip:
+        filter.append({'Name': 'private-ip-address', 'Values': ["*" + arg.private_ip + "*"]})
+
     if arg.id_list:
         InstanceIds=arg.id_list
     
@@ -155,20 +180,24 @@ def main():
           target='public_ip'
        if arg.connection_method == 'bastion-host':
           target='hostname'
+
        for item in hosts:
-          names = names + " " + item["hostname"] + "(" + item["id"] + ")"
-       print("\nCommand to execute: %s" % arg.execute)
-       print("Executed by: %s" % arg.user)
-       print("Hosts list: %s\n" % names) 
-       for item in hosts:
-          if item["status"] == 'running':
-             if item["public_ip"] is None and arg.connection_method == 'direct':
-                print("::: %s (%s) is not reachable using direct method. Use the bastion-host instead  (command execution skiped)" % (item["hostname"], item["id"]))
-                continue
-             print("::: %s (%s)" % (item["hostname"], item["id"]))
-             print(execute_cmd(item[target], arg.user, arg.execute, arg.connection_method))
-          else:
-             print("::: %s (%s) is not running (command execution skiped)" % (item["hostname"], item["id"]))
+          names = names + " " + "[green]" + item["hostname"] + "[/green]:[cyan]" + item["id"] + "[/cyan] " 
+
+       console = Console() 
+       console.print("Command to execute: %s" % arg.execute)
+       console.print("Executed by: %s" % arg.user)
+       console.print("Hosts list: %s" % names)
+       with console.status("[bold green]Working on remote execution...[/bold green]") as status:
+           for item in hosts:
+              if item["status"] == 'running':
+                 if item["public_ip"] is None and arg.connection_method == 'direct':
+                    console.rule("[green]%s[/green][cyan] : %s[/cyan] is not reachable using direct method. Use the bastion-host instead  (command execution skiped)" % (item["hostname"], item["id"]))
+                    continue
+                 console.rule("[green]%s[/green][cyan] : %s[/cyan]" % (item["hostname"], item["id"]), align='center')
+                 print(execute_cmd(item[target], arg.user, arg.execute, arg.connection_method))
+              else:
+                 console.rule("[green]%s[/green][cyan] : %s[/cyan] is not running (command execution skiped)" % (item["hostname"], item["id"]))
 
 if __name__ == '__main__':
     sys.exit(main())
